Index: tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/BuildCwbEncodeArgsFromWTC.java
===================================================================
--- tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/BuildCwbEncodeArgsFromWTC.java	(revision 803)
+++ tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/BuildCwbEncodeArgsFromWTC.java	(revision 804)
@@ -1,217 +0,0 @@
-// Copyright © 2010-2013 ENS de Lyon.
-// Copyright © 2007-2010 ENS de Lyon, CNRS, INRP, University of
-// Lyon 2, University of Franche-Comté, University of Nice
-// Sophia Antipolis, University of Paris 3.
-// 
-// The TXM platform is free software: you can redistribute it
-// and/or modify it under the terms of the GNU General Public
-// License as published by the Free Software Foundation,
-// either version 2 of the License, or (at your option) any
-// later version.
-// 
-// The TXM platform is distributed in the hope that it will be
-// useful, but WITHOUT ANY WARRANTY; without even the implied
-// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-// PURPOSE. See the GNU General Public License for more
-// details.
-// 
-// You should have received a copy of the GNU General
-// Public License along with the TXM platform. If not, see
-// http://www.gnu.org/licenses.
-// 
-// 
-// 
-// $LastChangedDate: 2013-08-29 14:23:55 +0200 (Thu, 29 Aug 2013) $
-// $LastChangedRevision: 2519 $
-// $LastChangedBy: nilskredens $ 
-//
-package org.txm.importer.cwb;
-
-import java.io.BufferedReader;
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.IOException;
-import java.io.InputStreamReader;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.LinkedList;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
-
-import javax.xml.stream.FactoryConfigurationError;
-import javax.xml.stream.XMLStreamException;
-
-import org.txm.core.messages.TXMCoreMessages;
-
-// TODO: Auto-generated Javadoc
-/**
- * build the sAttributes and pAttributs List from an xmlfile pAttributes
- * (attributes of tei:w tags) and the sAttributes (attributes + max inclusion of
- * tags).
- *
- * @author mdecorde
- */
-public class BuildCwbEncodeArgsFromWTC {
-
-	/** The stack. */
-	LinkedList<String> stack = new LinkedList<String>();
-
-	/** The tagcount. */
-	HashMap<String, Integer> tagcount = new HashMap<String, Integer>();
-
-	/** The tagmax. */
-	HashMap<String, Integer> tagmax = new HashMap<String, Integer>();
-
-	/** The tagattrs. */
-	HashMap<String, HashSet<String>> tagattrs = new HashMap<String, HashSet<String>>();
-	int nWordProps = 0;
-	
-	/**
-	 * process !!!.
-	 *
-	 * @param cqpfile the xmlfile
-	 * @param wordstag the wordstag
-	 * @return true if successful
-	 * @throws XMLStreamException the xML stream exception
-	 * @throws FactoryConfigurationError the factory configuration error
-	 * @throws IOException Signals that an I/O exception has occurred.
-	 */
-	public boolean process(File cqpfile)
-			throws XMLStreamException, FactoryConfigurationError, IOException {
-		if (cqpfile == null || !cqpfile.exists()) {
-			System.out.println(TXMCoreMessages.bind(TXMCoreMessages.BuildCwbEncodeArgs_0, cqpfile));
-			return false;
-		}
-
-		BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream(cqpfile), "UTF-8"));
-
-		String line = reader.readLine();
-		String localname;
-		
-		
-		Pattern p = Pattern.compile("(([^= ]+)=\"([^\"]+)\")");
-		//for (int event = parser.next(); event != XMLStreamConstants.END_DOCUMENT; event = parser.next()) {
-		for(; line != null ; line = reader.readLine()) {
-
-			if (line.startsWith("</") && line.endsWith(">")) { // END_ELEMENT
-				int idx = line.indexOf(" ");
-				if (idx == -1) idx = line.indexOf(">");
-				localname = line.substring(2, idx);
-
-				if (stack.size() > 0) {
-					stack.pop();
-					int count = tagcount.get(localname);
-					count--;
-					tagcount.put(localname, count);// decrement the
-					// recursion counter of the tag
-				}
-
-			} else if (line.startsWith("<") && line.endsWith("/>")) { // EMPTY_ELEMENT
-				// ignore milestones
-			} else if (line.startsWith("<") && line.endsWith(">")) { // START_ELEMENT
-				int idx = line.indexOf(" ");
-				if (idx == -1) idx = line.indexOf(">"); // no attributes
-				localname = line.substring(1, idx);
-
-				stack.push(localname);
-
-				if (!tagattrs.containsKey(localname))// initialize
-					// HashMaps
-				{
-					tagattrs.put(localname, new HashSet<String>());
-					tagcount.put(localname, 0);
-					tagmax.put(localname, 0);
-				}
-
-				Matcher m = p.matcher(line);
-				while (m.find()) {
-					if (m.groupCount() == 3) {
-						tagattrs.get(localname).add(m.group(2));
-					}
-				}
-
-				int count = tagcount.get(localname);
-				count++;
-				tagcount.put(localname, count);// increment the
-				// recursion counter of the tag
-				int max = tagmax.get(localname);
-				if (max < count)
-					tagmax.put(localname, count);// update max
-				// recursion of the tag
-
-			} else { // WORD LINE
-				if (nWordProps == 0) {
-					//System.out.println("Line: "+line);
-					String[] split = line.split("\t");
-					nWordProps = split.length;
-					//System.out.println("nprops: "+nWordProps);
-				}
-				
-			}
-		} // end while
-		reader.close();
-		return true;
-	}
-
-	/**
-	 * Gets the p attributes.
-	 *
-	 * @return the p attributes
-	 */
-	public Collection<String> getPAttributes() {
-		ArrayList<String> props = new ArrayList<String>();
-		for( int i = 1 ; i < nWordProps ; i++) { // don't count the "word" property
-			props.add("p"+i);
-		}
-		return props;
-	}
-
-	/**
-	 * Gets the s attributes.
-	 *
-	 * @return the s attributes
-	 */
-	public Collection<String> getSAttributes() {
-		ArrayList<String> rez = new ArrayList<String>();
-
-		for (String tag : tagattrs.keySet()) {
-			String s = tag.toLowerCase();
-			s += ":"; //$NON-NLS-1$
-
-			if (tagmax.get(tag) >= 0)
-				s += "" + (tagmax.get(tag) - 1); //$NON-NLS-1$
-
-			for (String attr : tagattrs.get(tag))
-				s += "+" + attr.toLowerCase(); //$NON-NLS-1$
-			rez.add(s);
-		}
-		return rez;
-	}
-
-	/**
-	 * The main method.
-	 *
-	 * @param args the arguments
-	 */
-	public static void main(String[] args) {
-		try {
-			BuildCwbEncodeArgsFromWTC argsgetter = new BuildCwbEncodeArgsFromWTC();
-			argsgetter.process(new File(
-					"/home/mdecorde/xml/cqp/discours.cqp")); //$NON-NLS-1$
-
-			System.out.println("pAttributes : " + argsgetter.getPAttributes()); //$NON-NLS-1$
-			System.out.println("sAttributes : " + argsgetter.getSAttributes()); //$NON-NLS-1$
-		} catch (XMLStreamException e) {
-			// TODO Auto-generated catch block
-			org.txm.utils.logger.Log.printStackTrace(e);
-		} catch (FactoryConfigurationError e) {
-			// TODO Auto-generated catch block
-			org.txm.utils.logger.Log.printStackTrace(e);
-		} catch (IOException e) {
-			// TODO Auto-generated catch block
-			org.txm.utils.logger.Log.printStackTrace(e);
-		}
-	}
-}
Index: tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/CwbEncode.java
===================================================================
--- tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/CwbEncode.java	(revision 803)
+++ tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/CwbEncode.java	(revision 804)
@@ -338,11 +338,11 @@
 	}
 
 	/**
-	 * concatenates WTC files into one master WTC file and wraps with the 'txmcorpus' structure. 
+	 * concatenates CQP files into one master CQP file and wraps with the 'txmcorpus' structure. 
 	 * 
 	 * @param cqpFiles
 	 * @param allcqpFile
-	 * @return true if the WTC files are concatenated
+	 * @return true if the CQP files are concatenated
 	 * @throws IOException
 	 */
 	public static boolean concat(ArrayList<File> cqpFiles, File allcqpFile) throws IOException {
Index: tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/BuildCwbEncodeArgsFromCQP.java
===================================================================
--- tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/BuildCwbEncodeArgsFromCQP.java	(revision 0)
+++ tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/BuildCwbEncodeArgsFromCQP.java	(revision 804)
@@ -0,0 +1,217 @@
+// Copyright © 2010-2013 ENS de Lyon.
+// Copyright © 2007-2010 ENS de Lyon, CNRS, INRP, University of
+// Lyon 2, University of Franche-Comté, University of Nice
+// Sophia Antipolis, University of Paris 3.
+// 
+// The TXM platform is free software: you can redistribute it
+// and/or modify it under the terms of the GNU General Public
+// License as published by the Free Software Foundation,
+// either version 2 of the License, or (at your option) any
+// later version.
+// 
+// The TXM platform is distributed in the hope that it will be
+// useful, but WITHOUT ANY WARRANTY; without even the implied
+// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+// PURPOSE. See the GNU General Public License for more
+// details.
+// 
+// You should have received a copy of the GNU General
+// Public License along with the TXM platform. If not, see
+// http://www.gnu.org/licenses.
+// 
+// 
+// 
+// $LastChangedDate: 2013-08-29 14:23:55 +0200 (Thu, 29 Aug 2013) $
+// $LastChangedRevision: 2519 $
+// $LastChangedBy: nilskredens $ 
+//
+package org.txm.importer.cwb;
+
+import java.io.BufferedReader;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.io.InputStreamReader;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.LinkedList;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
+
+import javax.xml.stream.FactoryConfigurationError;
+import javax.xml.stream.XMLStreamException;
+
+import org.txm.core.messages.TXMCoreMessages;
+
+// TODO: Auto-generated Javadoc
+/**
+ * build the sAttributes and pAttributs List from an xmlfile pAttributes
+ * (attributes of tei:w tags) and the sAttributes (attributes + max inclusion of
+ * tags).
+ *
+ * @author mdecorde
+ */
+public class BuildCwbEncodeArgsFromCQP {
+
+	/** The stack. */
+	LinkedList<String> stack = new LinkedList<String>();
+
+	/** The tagcount. */
+	HashMap<String, Integer> tagcount = new HashMap<String, Integer>();
+
+	/** The tagmax. */
+	HashMap<String, Integer> tagmax = new HashMap<String, Integer>();
+
+	/** The tagattrs. */
+	HashMap<String, HashSet<String>> tagattrs = new HashMap<String, HashSet<String>>();
+	int nWordProps = 0;
+	
+	/**
+	 * process !!!.
+	 *
+	 * @param cqpfile the xmlfile
+	 * @param wordstag the wordstag
+	 * @return true if successful
+	 * @throws XMLStreamException the xML stream exception
+	 * @throws FactoryConfigurationError the factory configuration error
+	 * @throws IOException Signals that an I/O exception has occurred.
+	 */
+	public boolean process(File cqpfile)
+			throws XMLStreamException, FactoryConfigurationError, IOException {
+		if (cqpfile == null || !cqpfile.exists()) {
+			System.out.println(TXMCoreMessages.bind(TXMCoreMessages.BuildCwbEncodeArgs_0, cqpfile));
+			return false;
+		}
+
+		BufferedReader reader = new BufferedReader(new InputStreamReader(new FileInputStream(cqpfile), "UTF-8"));
+
+		String line = reader.readLine();
+		String localname;
+		
+		
+		Pattern p = Pattern.compile("(([^= ]+)=\"([^\"]+)\")");
+		//for (int event = parser.next(); event != XMLStreamConstants.END_DOCUMENT; event = parser.next()) {
+		for(; line != null ; line = reader.readLine()) {
+
+			if (line.startsWith("</") && line.endsWith(">")) { // END_ELEMENT
+				int idx = line.indexOf(" ");
+				if (idx == -1) idx = line.indexOf(">");
+				localname = line.substring(2, idx);
+
+				if (stack.size() > 0) {
+					stack.pop();
+					int count = tagcount.get(localname);
+					count--;
+					tagcount.put(localname, count);// decrement the
+					// recursion counter of the tag
+				}
+
+			} else if (line.startsWith("<") && line.endsWith("/>")) { // EMPTY_ELEMENT
+				// ignore milestones
+			} else if (line.startsWith("<") && line.endsWith(">")) { // START_ELEMENT
+				int idx = line.indexOf(" ");
+				if (idx == -1) idx = line.indexOf(">"); // no attributes
+				localname = line.substring(1, idx);
+
+				stack.push(localname);
+
+				if (!tagattrs.containsKey(localname))// initialize
+					// HashMaps
+				{
+					tagattrs.put(localname, new HashSet<String>());
+					tagcount.put(localname, 0);
+					tagmax.put(localname, 0);
+				}
+
+				Matcher m = p.matcher(line);
+				while (m.find()) {
+					if (m.groupCount() == 3) {
+						tagattrs.get(localname).add(m.group(2));
+					}
+				}
+
+				int count = tagcount.get(localname);
+				count++;
+				tagcount.put(localname, count);// increment the
+				// recursion counter of the tag
+				int max = tagmax.get(localname);
+				if (max < count)
+					tagmax.put(localname, count);// update max
+				// recursion of the tag
+
+			} else { // WORD LINE
+				if (nWordProps == 0) {
+					//System.out.println("Line: "+line);
+					String[] split = line.split("\t");
+					nWordProps = split.length;
+					//System.out.println("nprops: "+nWordProps);
+				}
+				
+			}
+		} // end while
+		reader.close();
+		return true;
+	}
+
+	/**
+	 * Gets the p attributes.
+	 *
+	 * @return the p attributes
+	 */
+	public Collection<String> getPAttributes() {
+		ArrayList<String> props = new ArrayList<String>();
+		for( int i = 1 ; i < nWordProps ; i++) { // don't count the "word" property
+			props.add("p"+i);
+		}
+		return props;
+	}
+
+	/**
+	 * Gets the s attributes.
+	 *
+	 * @return the s attributes
+	 */
+	public Collection<String> getSAttributes() {
+		ArrayList<String> rez = new ArrayList<String>();
+
+		for (String tag : tagattrs.keySet()) {
+			String s = tag.toLowerCase();
+			s += ":"; //$NON-NLS-1$
+
+			if (tagmax.get(tag) >= 0)
+				s += "" + (tagmax.get(tag) - 1); //$NON-NLS-1$
+
+			for (String attr : tagattrs.get(tag))
+				s += "+" + attr.toLowerCase(); //$NON-NLS-1$
+			rez.add(s);
+		}
+		return rez;
+	}
+
+	/**
+	 * The main method.
+	 *
+	 * @param args the arguments
+	 */
+	public static void main(String[] args) {
+		try {
+			BuildCwbEncodeArgsFromCQP argsgetter = new BuildCwbEncodeArgsFromCQP();
+			argsgetter.process(new File(
+					"/home/mdecorde/xml/cqp/discours.cqp")); //$NON-NLS-1$
+
+			System.out.println("pAttributes : " + argsgetter.getPAttributes()); //$NON-NLS-1$
+			System.out.println("sAttributes : " + argsgetter.getSAttributes()); //$NON-NLS-1$
+		} catch (XMLStreamException e) {
+			// TODO Auto-generated catch block
+			org.txm.utils.logger.Log.printStackTrace(e);
+		} catch (FactoryConfigurationError e) {
+			// TODO Auto-generated catch block
+			org.txm.utils.logger.Log.printStackTrace(e);
+		} catch (IOException e) {
+			// TODO Auto-generated catch block
+			org.txm.utils.logger.Log.printStackTrace(e);
+		}
+	}
+}

Property changes on: tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/BuildCwbEncodeArgsFromCQP.java
___________________________________________________________________
Added: svn:mime-type
   + text/plain

Index: tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/BuildAlignOut.java
===================================================================
--- tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/BuildAlignOut.java	(revision 803)
+++ tmp/org.txm.searchengine.cqp.core/src/org/txm/importer/cwb/BuildAlignOut.java	(revision 804)
@@ -8,7 +8,7 @@
 
 import org.txm.utils.io.IOUtils;
 /**
- * Create the CWB "align.out" file usually created with cwb-align using 2 WTC files. The alignement structure and property is not checked. Only structure order is used.
+ * Create the CWB "align.out" file usually created with cwb-align using 2 CQP files. The alignement structure and property is not checked. Only structure order is used.
  * 
  * @author mdecorde
  *
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/scripts/teitxm/AnnotateWTC.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/scripts/teitxm/AnnotateWTC.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/scripts/teitxm/AnnotateWTC.groovy	(revision 804)
@@ -46,7 +46,7 @@
  * creates $rootDirFile/interp and $rootDirFile/treetagger
  *
  */
-class AnnotateWTC {
+class AnnotateCQP {
 
 	/** The debug. */
 	boolean debug = true;
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xmltxm/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xmltxm/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xmltxm/compiler.groovy	(revision 804)
@@ -154,7 +154,7 @@
 			output = new OutputStreamWriter(new BufferedOutputStream(new FileOutputStream(f,f.exists())) , "UTF-8");
 			return true;
 		} catch (Exception e) {
-		println "Error while create WTC otput file: "+e
+		println "Error while create CQP otput file: "+e
 			e.printStackTrace();
 
 			return false;
@@ -182,7 +182,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtc(File cqpFile)
+	public boolean transfomFileCqp(File cqpFile)
 	{
 		createOutput(cqpFile);
 		String headvalue=""
@@ -324,7 +324,7 @@
 			parser.close();
 		}
 		catch (Exception ex) {
-			System.out.println("Error while writing WTC file $ex");
+			System.out.println("Error while writing CQP file $ex");
 			ex.printStackTrace();
 			return false;
 		}
@@ -377,7 +377,7 @@
 			output.write("<txmcorpus lang=\""+lang+"\">\n");
 			output.close();
 		}
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		def builder = null;
 		for (File f : files) {
 			counttext++;
@@ -388,7 +388,7 @@
 				String txtname = f.getName().substring(0,f.getName().length()-4);
 				builder = new compiler(f.toURI().toURL(), txtname, corpusname.toLowerCase(), "default");
 				builder.setLang(lang);
-				if(!builder.transfomFileWtc(cqpFile))
+				if(!builder.transfomFileCqp(cqpFile))
 					return false;
 			}
 		}
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/fleurs/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/fleurs/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/fleurs/compiler.groovy	(revision 804)
@@ -146,7 +146,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtc(String dirPathName, String fileName)
+	public boolean transfomFileCqp(String dirPathName, String fileName)
 	{
 		createOutput(dirPathName, fileName);
 		
@@ -245,7 +245,7 @@
 		new File(rootDir,"cqp/").mkdir();
 		new File(rootDir,"registry/").mkdir();
 		
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		List<File> files = new File(rootDir,"txm").listFiles();
 		for (File f : files) {
 			if (!f.exists()) {
@@ -257,7 +257,7 @@
 				String txtname = f.getName().substring(0,f.getName().length()-4);
 				def builder = new compiler(f.toURL(), txtname, "fleurs", "default");
 				builder.setLang lang
-				builder.transfomFileWtc(rootDir,"cqp/fleurs.cqp");
+				builder.transfomFileCqp(rootDir,"cqp/fleurs.cqp");
 			}
 		}
 		
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/XMLTXM2WTC.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/XMLTXM2WTC.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/XMLTXM2WTC.groovy	(revision 804)
@@ -38,13 +38,13 @@
 // TODO: Auto-generated Javadoc
 
 /**
- * The Class XMLTXM2WTC.
+ * The Class XMLTXM2CQP.
  *
  * @author mdecorde
  * simple transofmration of a xml-tei-txm file into cqp file
  */
 
-class XMLTXM2WTC
+class XMLTXM2CQP
 {
 	
 	/** The url. */
@@ -119,7 +119,7 @@
 	 *
 	 * @param url the url
 	 */
-	public XMLTXM2WTC(URL url){
+	public XMLTXM2CQP(URL url){
 		try {
 			this.url = url;
 			inputData = url.openStream();
@@ -494,8 +494,8 @@
 		new File(rootDir,"out").deleteDir()
 		new File(rootDir,"out").mkdir()
 		
-		System.out.println("XMLTXM2WTC : "+srcfile+" >> "+cqpfile);
-		def builder = new XMLTXM2WTC(srcfile.toURL());
+		System.out.println("XMLTXM2CQP : "+srcfile+" >> "+cqpfile);
+		def builder = new XMLTXM2CQP(srcfile.toURL());
 		def balises = ["text", "s"];
 		builder.setBalisesToKeep(balises);
 		builder.transformFile(cqpfile);
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/limsi/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/limsi/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/limsi/compiler.groovy	(revision 804)
@@ -106,7 +106,7 @@
 		new File(binDir, "data").mkdir()
 		new File(binDir, "registry").mkdir()
 
-		//1- Merge WTC files
+		//1- Merge CQP files
 		if (annotationSuccess) {
 			File annotationDir = new File(binDir, "annotations")
 			if (annotationDir.exists()) txmDir = annotationDir;
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/limsi/limsiLoader.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/limsi/limsiLoader.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/limsi/limsiLoader.groovy	(revision 804)
@@ -157,7 +157,7 @@
 	if (MONITOR != null) MONITOR.worked(20, "ANNOTATE")
 	println "-- ANNOTATE CQP- Running NLP tools"
 	boolean annotationSuccess = false;
-	if (annotate && new AnnotateWTC().run(binDir, txmDir, model+".par")) {
+	if (annotate && new AnnotateCQP().run(binDir, txmDir, model+".par")) {
 		annotationSuccess = true;
 	}
 
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xtz/Compiler.java
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xtz/Compiler.java	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xtz/Compiler.java	(revision 804)
@@ -6,7 +6,7 @@
 import org.txm.utils.DeleteDir;
 
 /**
- * Takes XML-TXM files, build the WTC files and call cwb utils
+ * Takes XML-TXM files, build the CQP files and call cwb utils
  * 
  * @author mdecorde
  *
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xtz/XTZCompiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xtz/XTZCompiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xtz/XTZCompiler.groovy	(revision 804)
@@ -41,7 +41,7 @@
 		if (files == null) files = inputDirectory.listFiles();
 		
 		if (!doScanStep()) return;
-		if (!doWTCStep()) return;
+		if (!doCQPStep()) return;
 		if (!doCWBEncodeStep()) return;
 		if (!doCWBMakeAllStep()) return;
 		
@@ -108,8 +108,8 @@
 	}
 
 	def cqpFiles = []
-	public boolean doWTCStep() {
-		println "-- Building WTC files $inputDirectory..."
+	public boolean doCQPStep() {
+		println "-- Building CQP files $inputDirectory..."
 		cqpDirectory.mkdir(); // if not created
 		
 		ConsoleProgressBar cpb = new ConsoleProgressBar(files.size())
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/ImportInCWB.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/ImportInCWB.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/ImportInCWB.groovy	(revision 804)
@@ -122,10 +122,10 @@
 		CwbMakeAll cwbMa = new CwbMakeAll();
 		
 		GraalImportCqp traitTxt = new GraalImportCqp(new URL("file:///"+ inDir + "/" + inFile+ ".xml"));
-		traitTxt.transfomFileWtc(outDir+"/cqp/", outFile + ".cqp");
+		traitTxt.transfomFileCqp(outDir+"/cqp/", outFile + ".cqp");
 		
 		traitTxt = new GraalImportCqp(new URL("file:///"+ inDir + "/" + inFile2+ ".xml"));
-		traitTxt.transfomFileWtcBrut(outDir+"/cqp/", outFile2 + ".cqp");
+		traitTxt.transfomFileCqpBrut(outDir+"/cqp/", outFile2 + ".cqp");
 		
 		System.out.println("--Building index files ...") 
 		String[] pAttributecm = ["pos", "q", "supplied", "col", "line", "id", "dipl", "facs"];
@@ -159,10 +159,10 @@
 	 */
 	public void run() 
 	{
-		System.out.println "Starting script : importWTC.groovy ...";
+		System.out.println "Starting script : importCQP.groovy ...";
 		System.setProperty("javax.xml.transform.TransformerFactory",  
 				 			"net.sf.saxon.TransformerFactoryImpl");  
-		this.importWTC();
+		this.importCQP();
 		System.out.println "GraalImport.groovy done."
 	}
 }
\ No newline at end of file
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/qgraalLoader.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/qgraalLoader.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/qgraalLoader.groovy	(revision 804)
@@ -56,7 +56,7 @@
 //
 //String pathToCwbBinaries = org.txm.Toolbox.getParam(org.txm.Toolbox.INSTALL_DIR)+"/cwb/bin/";//chemin vers executable cqp de l'installation
 //
-//	//2- create GSP & import to WTC
+//	//2- create GSP & import to CQP
 //	println "EDITION"
 //	def edition = new BuildGraalGSP(rootDir,//rootdir
 //	pathToCwbBinaries// cwb utils dir
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/BuildGraalGSP.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/BuildGraalGSP.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/BuildGraalGSP.groovy	(revision 804)
@@ -128,7 +128,7 @@
 			return false;
 		}
 		
-		def timportWTCestG
+		def timportCQPestG
 		def nPage;
 		def temp;
 		def BBM;
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/GraalImportCqp.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/GraalImportCqp.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/graal/GraalImportCqp.groovy	(revision 804)
@@ -101,7 +101,7 @@
 	 * @param fileName the outfile name
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtc(String dirPathName, String fileName){
+	public boolean transfomFileCqp(String dirPathName, String fileName){
 		if(findBody() && createOutput(dirPathName, fileName)){
 			String idColumn;
 			int idParagraph = 0;
@@ -259,7 +259,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtcBrut(String dirPathName, String fileName){
+	public boolean transfomFileCqpBrut(String dirPathName, String fileName){
 		if(findBody() && createOutput(dirPathName, fileName)){
 			String idColumn = "";
 			int idParagraph = 0;
@@ -383,10 +383,10 @@
 
 		if (args.length == 0) {
 			GraalImportCqp traitTxt = new GraalImportCqp(new URL("file://"+ inDir + "/" + inFile));
-			traitTxt.transfomFileWtc("/home/ayepdieu/srcQuete/result", "graal.cqp");
+			traitTxt.transfomFileCqp("/home/ayepdieu/srcQuete/result", "graal.cqp");
 		}else if(args.length == 3){
 			GraalImportCqp traitTxt = new GraalImportCqp(new URL(args[0]));
-			traitTxt.transfomFileWtc(args[1], args[2]);
+			traitTxt.transfomFileCqp(args[1], args[2]);
 		}else{
 			System.err.println("Usage: java XHTMLOutliner url" );
 			return;
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/hyperprince/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/hyperprince/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/hyperprince/compiler.groovy	(revision 804)
@@ -162,7 +162,7 @@
 	 * @param idtext the idtext
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtc(String dirPathName, String fileName,idtext)
+	public boolean transfomFileCqp(String dirPathName, String fileName,idtext)
 	{
 		createOutput(dirPathName, fileName);
 		
@@ -328,7 +328,7 @@
 		new File(rootDir,"cqp/").mkdir();
 		new File(rootDir,"registry/").mkdir();
 		
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		List<File> files = new File(rootDir,"txm").listFiles();
 		for(File f : files) {
 			if(!f.exists()) {
@@ -340,7 +340,7 @@
 				String txtname = f.getName().substring(0,f.getName().length()-4);
 				def builder = new compiler(f.toURL(),txtname, "hyperprince", "default");
 				builder.setLang lang
-				builder.transfomFileWtc(rootDir,"cqp/hyperprince.cqp",f.getName());
+				builder.transfomFileCqp(rootDir,"cqp/hyperprince.cqp",f.getName());
 			}
 		}
 		
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/perrault/allimport.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/perrault/allimport.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/perrault/allimport.groovy	(revision 804)
@@ -420,7 +420,7 @@
  * @param fileName the file name
  * @return true, if successful
  */
-public boolean transfomFileWtc(String dirPathName, String fileName)
+public boolean transfomFileCqp(String dirPathName, String fileName)
 {
 	createOutput(dirPathName, fileName);
 
@@ -597,7 +597,7 @@
 
 	String textid="";
 	int counttext =0;
-	//1- Transform into WTC file
+	//1- Transform into CQP file
 	for(File f : files)
 	{
 		counttext++;
@@ -609,7 +609,7 @@
 		{
 			println("process file "+f)
 			compil(f.toURL(),"text"+counttext,"perrault","default");
-			transfomFileWtc(rootDir+"cqp","perrault.cqp");
+			transfomFileCqp(rootDir+"cqp","perrault.cqp");
 		}
 	}
 
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/perrault/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/perrault/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/perrault/compiler.groovy	(revision 804)
@@ -162,7 +162,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtc(String dirPathName, String fileName)
+	public boolean transfomFileCqp(String dirPathName, String fileName)
 	{
 		createOutput(dirPathName, fileName);
 		
@@ -340,7 +340,7 @@
 		
 		String textid="";
 		int counttext =0;
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		for(File f : files)
 		{
 			counttext++;
@@ -354,7 +354,7 @@
 				String txtname = f.getName().substring(0,f.getName().length()-4);
 				def builder = new compiler(f.toURL(), txtname, "perrault", "default");
 				builder.setLang(lang);
-				builder.transfomFileWtc(rootDir+"cqp","perrault.cqp");
+				builder.transfomFileCqp(rootDir+"cqp","perrault.cqp");
 			}
 		}
 		
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xml/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xml/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xml/compiler.groovy	(revision 804)
@@ -212,7 +212,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtc(File cqpFile, HashMap<String, String> textmetadata)
+	public boolean transfomFileCqp(File cqpFile, HashMap<String, String> textmetadata)
 	{
 		if (!createOutput(cqpFile))
 			return false;
@@ -465,7 +465,7 @@
 		String textid = ""
 		int counttext = 0
 		List<File> files = txmDir.listFiles()
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		def builder = null
 
 		//start corpus
@@ -522,7 +522,7 @@
 				String txtname = f.getName().substring(0,f.getName().length()-4)
 				builder = new compiler(f.toURI().toURL(), txtname, corpusname, "default")
 				builder.setLang(lang);
-				if (!builder.transfomFileWtc(cqpFile, textmetadata)) {
+				if (!builder.transfomFileCqp(cqpFile, textmetadata)) {
 					println("Failed to compile "+f)
 				}
 			}
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/bfm/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/bfm/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/bfm/compiler.groovy	(revision 804)
@@ -60,7 +60,7 @@
 
 // TODO: Auto-generated Javadoc
 /**
- * Produce WTC files from the TEI-TXM files. <br/>
+ * Produce CQP files from the TEI-TXM files. <br/>
  * - Read texts metadata with XPath queries <br/>
  * - Add the following word properties : sic, abbr, orig, lb and pb <br/>
  * - Keep &lt;front>, &lt;body> and &lt;back> for each text <br/>
@@ -250,7 +250,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	private boolean transfomFileWtc(File cqpFile)
+	private boolean transfomFileCqp(File cqpFile)
 	{
 		try {
 			if (!createOutput(cqpFile)) return false;
@@ -838,7 +838,7 @@
 			output.close();
 		}
 		
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		for (File f : files) {
 			counttext++;
 			if (!f.exists()) {
@@ -848,7 +848,7 @@
 				String txtname = f.getName().substring(0, f.getName().length()-4);
 				def builder = new compiler(f.toURI().toURL(), txtname, corpusname, "default", metadataXPath);
 				builder.setLang(lang)
-				if (!builder.transfomFileWtc(cqpFile)) {
+				if (!builder.transfomFileCqp(cqpFile)) {
 					println "Failed to compile "+f
 				}
 				builder.setAnnotationDone(this.annotate_status);
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/tmx/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/tmx/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/tmx/compiler.groovy	(revision 804)
@@ -189,7 +189,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtc(String dirPathName, String fileName)
+	public boolean transfomFileCqp(String dirPathName, String fileName)
 	{
 		createOutput(dirPathName, fileName);
 
@@ -477,9 +477,9 @@
 			new File(rootDir, "txm/"+cqpName.toUpperCase()).mkdir();
 		}
 
-		//1- Transform into WTC file and build a corpus per file
+		//1- Transform into CQP file and build a corpus per file
 		Collections.sort(files);
-		def anaTypesPerWtc = [:];
+		def anaTypesPerCqp = [:];
 		def builder = null;
 		for (int group : langGroups.keySet()) {
 			//String lang = langs.get(langGroups.get(group)[0]);
@@ -503,8 +503,8 @@
 				txtname = txtname.substring(0, txtname.lastIndexOf("_"));
 				seg_id = segs_id.get(group);
 				builder = new compiler(f.toURI().toURL(), txtname, basename, "default", tuprops);
-				builder.transfomFileWtc(rootDir+"/cqp",cqpName+".cqp");
-				anaTypesPerWtc[cqpName] = builder.getAnaTypes();
+				builder.transfomFileCqp(rootDir+"/cqp",cqpName+".cqp");
+				anaTypesPerCqp[cqpName] = builder.getAnaTypes();
 				segs_id.put(group, seg_id);
 
 				// move xml-txm file
@@ -534,7 +534,7 @@
 			String corpusname = cqpfile.getName();
 			
 			corpusname = corpusname.substring(0, corpusname.length()-4);
-			def corpusAnaTypes = anaTypesPerWtc[corpusname];
+			def corpusAnaTypes = anaTypesPerCqp[corpusname];
 			
 			CwbEncode cwbEn = new CwbEncode();
 			cwbEn.setDebug(debug);
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/bvh/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/bvh/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/bvh/compiler.groovy	(revision 804)
@@ -44,7 +44,7 @@
 
 // TODO: Auto-generated Javadoc
 /**
- * Produce WTC files from TEI-TXM files. <br/>
+ * Produce CQP files from TEI-TXM files. <br/>
  * Add the following word properties : "frpos","frlemme","afrpos","afrlemme","id","page","line","orig","sic","abbr". <br/>
  * 
  * @author mdecorde
@@ -168,7 +168,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	private boolean transfomFileWtc(String dirPathName, String fileName)
+	private boolean transfomFileCqp(String dirPathName, String fileName)
 	{
 		createOutput(dirPathName, fileName);
 		
@@ -556,7 +556,7 @@
 		int counttext =0;
 		List<File> files = new File(rootDirFile,"txm").listFiles();
 		Collections.sort(files);
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		for(File f : files)
 		{
 			counttext++;
@@ -570,7 +570,7 @@
 				String txtname = f.getName().substring(0,f.getName().length()-4);
 				def builder = new compiler(f.toURL(),txtname, "bvh", "default");
 				builder.setLang lang
-				builder.transfomFileWtc(rootDir+"/cqp","bvh.cqp");
+				builder.transfomFileCqp(rootDir+"/cqp","bvh.cqp");
 			}
 		}
 		
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/RGAQCJ/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/RGAQCJ/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/RGAQCJ/compiler.groovy	(revision 804)
@@ -167,7 +167,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtc(String dirPathName, String fileName)
+	public boolean transfomFileCqp(String dirPathName, String fileName)
 	{
 		createOutput(dirPathName, fileName);
 		
@@ -526,7 +526,7 @@
 		String textid="";
 		int counttext =0;
 		List<File> files = new File(rootDirFile,"txm").listFiles();
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		for(File f : files)
 		{
 			counttext++;
@@ -539,7 +539,7 @@
 				println("process file "+f)
 				def builder = new compiler(f.toURL(),f.getName(),"bfm3tt","default");
 				builder.setLang(lang);
-				builder.transfomFileWtc(rootDir+"/cqp","bfm3tt.cqp");
+				builder.transfomFileCqp(rootDir+"/cqp","bfm3tt.cqp");
 			}
 		}
 		
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/RGAQCJ/importRGAQCJ.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/RGAQCJ/importRGAQCJ.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/RGAQCJ/importRGAQCJ.groovy	(revision 804)
@@ -175,7 +175,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtc(String dirPathName, String fileName)
+	public boolean transfomFileCqp(String dirPathName, String fileName)
 	{
 		if(findBody() && createOutput(dirPathName, fileName))
 		{
@@ -352,7 +352,7 @@
 		ArrayList<String> types = BuildXmlRGAQCJ.getAnatypes(rootDir, files);
 		println(types);
 		
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		File f = new File(rootDir+"cqp/","RGAQCJ.cqp");
 		f.delete();
 		
@@ -367,7 +367,7 @@
 			println("process file "+files[i])
 			String file = files[i]; 
 			def builder = new BuildXmlRGAQCJ(new File(rootDir+"/anainline/",file).toURL(),""+initiales.charAt(i),types);
-			builder.transfomFileWtc(rootDir+"cqp","RGAQCJ.cqp");
+			builder.transfomFileCqp(rootDir+"cqp","RGAQCJ.cqp");
 		}
 		
 		output = new OutputStreamWriter(new FileOutputStream(f,true) , "UTF-8");
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/cqp/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/cqp/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/cqp/compiler.groovy	(revision 804)
@@ -55,13 +55,13 @@
 	/** The dir. */
 	private def dir;
 
-	File srcWTCFile, srcRegistryFile;
+	File srcCQPFile, srcRegistryFile;
 
 	public def pAttributesList = [];
 	public def sAttributesList = [];
 
 	public compiler(File cqpFile, File registryFile) {
-		this.srcWTCFile = cqpFile;
+		this.srcCQPFile = cqpFile;
 		this.srcRegistryFile = registryFile
 	}
 
@@ -93,8 +93,8 @@
 			return false;
 		}
 
-		if (!srcWTCFile.exists()) {
-			println "Error: cannot find the WTC file $srcWTCFile"
+		if (!srcCQPFile.exists()) {
+			println "Error: cannot find the CQP file $srcCQPFile"
 			return false;
 		}
 
@@ -105,7 +105,7 @@
 		new File(binDir, "data").mkdir();
 		new File(binDir, "registry").mkdir();
 
-		FileCopy.copy(srcWTCFile, cqpFile);
+		FileCopy.copy(srcCQPFile, cqpFile);
 
 		//2- Import into CWB
 		def outDir = binDir.getAbsolutePath()+"/";
@@ -120,10 +120,10 @@
 
 		if (srcRegistryFile == null) {
 			println "WARNING: No registry file found in source directory"
-			println "We'll search for positional attributes and structural attributes in the WTC file"
+			println "We'll search for positional attributes and structural attributes in the CQP file"
 
 			// s attributes
-			BuildCwbEncodeArgsFromWTC argsgetter = new BuildCwbEncodeArgsFromWTC(); // XML stream
+			BuildCwbEncodeArgsFromCQP argsgetter = new BuildCwbEncodeArgsFromCQP(); // XML stream
 			argsgetter.process(cqpFile); //$NON-NLS-1$
 			sAttributesList = argsgetter.getSAttributes();
 
@@ -131,7 +131,7 @@
 			int nbAttr = -1;
 			File tmp = File.createTempFile("txm", ".cqp", cqpFile.getParentFile());
 			int wcounter = 1;
-			println "Adding the 'id' property to the WTC file and getting word properties number."
+			println "Adding the 'id' property to the CQP file and getting word properties number."
 			tmp.withWriter("UTF-8") { writer ->
 				cqpFile.eachLine("UTF-8") { line ->
 					if (!line.startsWith("<")) {
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/cqp/cqpLoader.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/cqp/cqpLoader.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/cqp/cqpLoader.groovy	(revision 804)
@@ -80,7 +80,7 @@
 	if (f.getName().endsWith(".cqp")) {
 		if (cqpFile == null) {
 			cqpFile = f;
-			println "Using WTC file : $cqpFile"
+			println "Using CQP file : $cqpFile"
 		}
 	} else if (f.getName().endsWith(".xml")) {
 
@@ -93,7 +93,7 @@
 }
 
 if (cqpFile == null) {
-	println "No WTC file in source directory: "+srcDir;
+	println "No CQP file in source directory: "+srcDir;
 	return false;
 }
 
@@ -125,8 +125,8 @@
 	List<String> NoSpaceBefore = LangFormater.getNoSpaceBefore(lang);
 	List<String> NoSpaceAfter = LangFormater.getNoSpaceAfter(lang);
 
-	File binWtcFile = new File(binDir,"cqp/"+corpusname+".cqp");
-	def ed = new pager(binWtcFile, outdir, NoSpaceBefore, NoSpaceAfter, wordsPerPage, basename, registryFile !=null, c.pAttributesList);
+	File binCqpFile = new File(binDir,"cqp/"+corpusname+".cqp");
+	def ed = new pager(binCqpFile, outdir, NoSpaceBefore, NoSpaceAfter, wordsPerPage, basename, registryFile !=null, c.pAttributesList);
 	def allIndexes = ed.getIdx();
 	def allPages = ed.getPageFiles();
 	for (String txtname : ed.getTextNames()) {
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/cqp/pager.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/cqp/pager.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/cqp/pager.groovy	(revision 804)
@@ -37,7 +37,7 @@
 import org.xml.sax.InputSource;
 import org.xml.sax.helpers.DefaultHandler;
 
-/** Build WTC corpus simple edition from a WTC file. 
+/** Build CQP corpus simple edition from a CQP file. 
  * 
  * @author mdecorde
  */
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/corptef/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/corptef/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/corptef/compiler.groovy	(revision 804)
@@ -166,7 +166,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtc(String dirPathName, String fileName)
+	public boolean transfomFileCqp(String dirPathName, String fileName)
 	{
 		createOutput(dirPathName, fileName);
 
@@ -526,7 +526,7 @@
 		int counttext =0;
 		List<File> files = new File(rootDirFile,"txm").listFiles();
 		Collections.sort(files);
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		for(File f : files)
 		{
 			counttext++;
@@ -540,7 +540,7 @@
 				String txtname = f.getName().substring(0,f.getName().length()-4);
 				def builder = new compiler(f.toURL(),txtname, "corptef", "default");
 				builder.setLang lang
-				builder.transfomFileWtc(rootDir+"/cqp","corptef.cqp");
+				builder.transfomFileCqp(rootDir+"/cqp","corptef.cqp");
 			}
 		}
 
Index: tmp/org.txm.rcp.feature/build.properties
===================================================================
--- tmp/org.txm.rcp.feature/build.properties	(revision 803)
+++ tmp/org.txm.rcp.feature/build.properties	(revision 804)
@@ -3,10 +3,14 @@
                TXM.sh
 
 root.linux.gtk.x86_64 = linux/
-root.linux.gtk.x86_64.permissions.755 = jre/bin/java
+root.linux.gtk.x86_64.permissions.755 = jre/bin/java,\
+	plugins/org.txm.libs.cqp.linux/res/linux32/,\
+	plugins/org.txm.libs.cqp.linux/res/linux64/
 
 root.macosx.cocoa.x86_64 = mac/
-
+root.macosx.cocoa.x86_64.permissions.755 = jre/bin/java,\
+	plugins/org.txm.libs.cqp.macosx/res/macosx/
+	
 root.win32.win32.x86_64 = win/,\
 						../org.txm.libs.cqp.win32/res/win64/dependencies/
 						
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/editors/imports/ImportModuleCustomization.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/editors/imports/ImportModuleCustomization.java	(revision 803)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/editors/imports/ImportModuleCustomization.java	(revision 804)
@@ -66,7 +66,7 @@
 		params.put(TEXTUALPLANS, false);
 		params.put(OPTIONS, false);
 		allParams.put("cqpLoader.groovy", params); //$NON-NLS-1$
-		names.put("cqpLoader.groovy", "WTC"); //$NON-NLS-1$ //$NON-NLS-2$
+		names.put("cqpLoader.groovy", "CQP"); //$NON-NLS-1$ //$NON-NLS-2$
 		
 		params = new HashMap<String, Boolean>();
 		params.put(PARALLEL, false);

Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/txt/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/txt/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/txt/compiler.groovy	(revision 804)
@@ -199,14 +199,14 @@
 			output.close();
 		}
 		
 		//1- Transform into WTC file
 		println("Compiling "+txmDir.listFiles().length+" files")
-		XMLTXM2WTC cqpbuilder = null;
+		XMLTXM2CQP cqpbuilder = null;
 		ArrayList<File> files = txmDir.listFiles();
 		Collections.sort(files);
 		for (File txmfile : files) {
 			print "."
-			cqpbuilder = new XMLTXM2WTC(txmfile.toURI().toURL());
+			cqpbuilder = new XMLTXM2CQP(txmfile.toURI().toURL());
 			String txtname = txmfile.getName().substring(0,txmfile.getName().length()-4);
 			cqpbuilder.setTextInfo(txtname, this.base, this.project);
 
@@ -199,14 +199,14 @@
 		}
 		
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		println("Compiling "+txmDir.listFiles().length+" files")
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/hyperbase/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/hyperbase/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/hyperbase/compiler.groovy	(revision 804)
@@ -212,8 +212,8 @@
 		int counttext =0;
 		List<File> files = txmDir.listFiles();
 		Collections.sort(files);
-		//1- Transform into WTC file
-		XMLTXM2WTC cqpbuilder = null;
+		//1- Transform into CQP file
+		XMLTXM2CQP cqpbuilder = null;
 		println("Compiling "+files.size()+" files")
 		for (File f : files) {
 			print "."
@@ -222,7 +222,7 @@
 				println("file "+f+ " does not exists")	
 			}
 			else {	
-				cqpbuilder = new XMLTXM2WTC(f.toURI().toURL());
+				cqpbuilder = new XMLTXM2CQP(f.toURI().toURL());
 				String txtname = f.getName().substring(0,f.getName().length()-4);
 				cqpbuilder.setTextInfo(txtname, corpusname, "project");
 
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/lasla/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/lasla/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/lasla/compiler.groovy	(revision 804)
@@ -199,7 +199,7 @@
 		String textid="";
 		int counttext =0;
 		List<File> files = new File(rootDirFile,"txm").listFiles();
 		//1- Transform into WTC file
 		def builder = null;
 		for(File f : files)
 		{
@@ -210,7 +210,7 @@
 			}
 			else
 			{	
-				cqpbuilder = new XMLTXM2WTC(f.toURL());
+				cqpbuilder = new XMLTXM2CQP(f.toURL());
 				String txtname = f.getName().substring(0,f.getName().length()-4);
 				cqpbuilder.setTextInfo(txtname, basename, "project");
 
@@ -199,7 +199,7 @@
 		int counttext =0;
 		List<File> files = new File(rootDirFile,"txm").listFiles();
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		def builder = null;
 		for(File f : files)
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xmltxmpara/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xmltxmpara/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/xmltxmpara/compiler.groovy	(revision 804)
@@ -177,7 +177,7 @@
 	 * @param fileName the file name
 	 * @return true, if successful
 	 */
-	public boolean transfomFileWtc(File cqpfile)
+	public boolean transfomFileCqp(File cqpfile)
 	{
 		createOutput(cqpfile);
 		String headvalue=""
@@ -379,7 +379,7 @@
 			output.close();
 		}
 		
 		//1- Transform into WTC file
 		def builder = null;
 		for (File f : files) {
 			counttext++;
@@ -390,7 +390,7 @@
 				String txtname = f.getName().substring(0,f.getName().length()-4);
 				builder = new compiler(f.toURL(), txtname, basename, "default");
 				builder.setLang(lang);
-				if (!builder.transfomFileWtc(cqpfile))
+				if (!builder.transfomFileCqp(cqpfile))
 					return false;
 			}
 		}
@@ -379,7 +379,7 @@
 		}
 		
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 		def builder = null;
 		for (File f : files) {
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/discours/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/discours/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/discours/compiler.groovy	(revision 804)
@@ -195,17 +195,17 @@
 		}
 
 		def second = 0
 		//1- Transform into WTC file
 
 		Collections.sort(files);
-		XMLTXM2WTC cqpbuilder = null;
+		XMLTXM2CQP cqpbuilder = null;
 		for (File f : files) {
 			if (second) { print(", ") }
 			if (second > 0 && (second % 5) == 0) println ""
 			print(f.getName().replaceFirst("\\.xml", ""));
 			second++
 
-			cqpbuilder = new XMLTXM2WTC(f.toURI().toURL());
+			cqpbuilder = new XMLTXM2CQP(f.toURI().toURL());
 			String txtname = f.getName().substring(0,f.getName().length()-4);
 			cqpbuilder.setTextInfo(txtname, corpusname, "project");
 
@@ -195,17 +195,17 @@
 
 		def second = 0
-		//1- Transform into WTC file
+		//1- Transform into CQP file
 
 		Collections.sort(files);
Index: tmp/org.txm.groovy.core/src/groovy/org/txm/importer/alceste/compiler.groovy
===================================================================
--- tmp/org.txm.groovy.core/src/groovy/org/txm/importer/alceste/compiler.groovy	(revision 803)
+++ tmp/org.txm.groovy.core/src/groovy/org/txm/importer/alceste/compiler.groovy	(revision 804)
@@ -206,8 +206,8 @@
 		}
 		
 		Collections.sort(files);
-		//1- Transform into WTC file
-		XMLTXM2WTC cqpbuilder = null;
+		//1- Transform into CQP file
+		XMLTXM2CQP cqpbuilder = null;
 		println("process "+files.size()+" files")
 		for (File f : files) {
 			print "."
@@ -215,7 +215,7 @@
 			if (!f.exists()) {
 				println("file "+f+ " does not exists")	
 			} else {			
-				cqpbuilder = new XMLTXM2WTC(f.toURI().toURL());
+				cqpbuilder = new XMLTXM2CQP(f.toURI().toURL());
 				String txtname = f.getName().substring(0, f.getName().length()-4);
 				cqpbuilder.setTextInfo(txtname, corpusname, "default");
 